@@ -2,18 +2,16 @@ package CXC::Number::Grid;
 
 # ABSTRACT: A class representing a one dimensional numeric grid
 
-use v5.26;
+use v5.28;
 
 use POSIX ();
 
-use Types::Standard
-  qw( ArrayRef Bool Dict Enum HashRef InstanceOf Optional Slurpy );
-use Type::Params qw( signature signature_for );
-use Ref::Util    qw[ is_plain_hashref is_blessed_ref ];
+use Types::Standard qw( ArrayRef Bool Dict Enum HashRef InstanceOf Optional Slurpy );
+use Type::Params    qw( signature signature_for );
+use Ref::Util       qw[ is_plain_hashref is_blessed_ref ];
 
 use CXC::Number::Grid::Types -types;
-use CXC::Number::Grid::Failure
-  qw( parameter_interface parameter_constraint internal );
+use CXC::Number::Grid::Failure qw( parameter_interface parameter_constraint internal );
 
 use CXC::Number::Grid::Tree;
 
@@ -21,9 +19,10 @@ use Safe::Isa;
 
 use Moo;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
-use constant GridObject => InstanceOf [ ( __PACKAGE__ ) ];
+use constant GridObject   => InstanceOf [ ( __PACKAGE__ ) ];
+use constant IncludeArray => ArrayRef [ Enum [ 0, 1 ] ];
 
 use experimental 'signatures';
 
@@ -39,10 +38,13 @@ use overload
   fallback => 1,
   bool     => sub { 1 };
 
-my $DEBUG = $ENV{ __PACKAGE__ . "_DEBUG" } // 0;
-
 BEGIN { with 'MooX::Tag::TO_HASH' }    # so can see has
 
+my sub _croak {
+    require Carp;
+    goto \&Carp::croak;
+}
+
 sub _convert ( $self, $bignum ) {
     require Ref::Util;
 
@@ -90,7 +92,7 @@ has _raw_edges => (
 has _include => (
     is       => 'lazy',
     init_arg => 'include',
-    isa      => ArrayRef [ Enum [ 0, 1 ] ],
+    isa      => IncludeArray,
     builder  => sub { [ ( 1 ) x $_[0]->nbins ] },
     to_hash  => 'include,if_exists',
 );
@@ -123,6 +125,74 @@ has _include => (
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+my sub edges_from_bounds;
+
+around BUILDARGS => sub ( $orig, $class, @args ) {
+
+    my $args = $class->$orig( @args );
+
+    _croak( 'specify either <edges> or <bounds> but not both' )
+      if exists $args->{edges} && exists $args->{bounds};
+
+    edges_from_bounds( $args )
+      if exists $args->{bounds};
+
+    return $args;
+
+};
+
+sub edges_from_bounds ( $args ) {
+
+    my $bounds = BinBounds->assert_coerce( $args->{bounds} );
+    my $includes;
+
+    if ( exists $args->{include} ) {
+        $includes = IncludeArray->assert_coerce( $args->{include} );
+        _croak( 'number of <include> flags does not match number of bounds pairs passed via <bounds>' )
+          unless ( $bounds->@* ) / 2 == $includes->@*;
+    }
+
+    my $n     = $bounds->@*;
+    my $b_idx = 0;
+    my $i_idx = 0;
+
+    my @edges   = $bounds->@[ $b_idx++, $b_idx++ ];
+    my @include = ( $includes->[ $i_idx++ ] // 1 );
+
+    while ( $b_idx < $n ) {
+        my ( $start, $end ) = $bounds->@[ $b_idx++, $b_idx++ ];
+        if ( $edges[-1] != $start ) {
+            push @edges,   $start;
+            push @include, 0;
+        }
+        push @edges, $end;
+        push @include, ( $includes->[ $i_idx++ ] // 1 );
+    }
+
+    delete $args->{bounds};
+    $args->{edges}   = \@edges;
+    $args->{include} = \@include;
+}
 
 sub BUILD ( $self, $ ) {
 
@@ -244,8 +314,7 @@ sub include ( $self ) {
 
 sub spacing ( $self ) {
     my $edges = $self->_raw_edges;
-    return $self->_convert(
-        [ map { ( $edges->[$_] - $edges->[ $_ - 1 ] ) } 1 .. $self->nbins ] );
+    return $self->_convert( [ map { ( $edges->[$_] - $edges->[ $_ - 1 ] ) } 1 .. $self->nbins ] );
 }
 
 
@@ -280,11 +349,11 @@ sub max ( $self ) {
 
 
 
-sub split ( $self ) {
+sub split ( $self ) {    ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
     my @grids;
 
-    my $last = 0;
+    my $last_idx = 0;
 
     my $include = $self->_include;
 
@@ -293,31 +362,33 @@ sub split ( $self ) {
         if ( !$include->[$idx] ) {
 
             # skip over consecutive excludes
-            ++$last, next if $last == $idx;
-
+            if ( $last_idx == $idx ) {
+                ++$last_idx;
+                next;
+            }
 
             # there's one more edge than include values
-            my @edges   = $self->_raw_edges->@[ $last .. $idx ];
-            my @include = $self->_include->@[ $last .. $idx - 1 ];
+            my @edges   = $self->_raw_edges->@[ $last_idx .. $idx ];
+            my @include = $self->_include->@[ $last_idx .. $idx - 1 ];
 
             push @grids,
               __PACKAGE__->new( {
                   edges   => \@edges,
                   include => \@include,
-                  oob     => $self->oob
+                  oob     => $self->oob,
               } );
 
-            $last = $idx + 1;
+            $last_idx = $idx + 1;
         }
     }
 
-    if ( $last < $self->_include->@* ) {
+    if ( $last_idx < $self->_include->@* ) {
         my $nbins = $self->nbins;
         push @grids,
           __PACKAGE__->new( {
-              edges   => [ $self->_raw_edges->@[ $last .. $nbins ] ],
-              include => [ $self->_include->@[ $last .. $nbins - 1 ] ],
-              oob     => $self->oob
+              edges   => [ $self->_raw_edges->@[ $last_idx .. $nbins ] ],
+              include => [ $self->_include->@[ $last_idx .. $nbins - 1 ] ],
+              oob     => $self->oob,
           } );
     }
 
@@ -460,10 +531,8 @@ sub overlay_n {
         ++$gi;
         my $edges   = $grid->_raw_edges;
         my $include = $grid->include;
-        $tr->range_set(
-            $edges->[$_],
-            $edges->[ $_ + 1 ],
-            [ $gi, $include->[$_] ] ) for 0 .. ( $grid->nbins - 1 );
+        $tr->range_set( $edges->[$_], $edges->[ $_ + 1 ], [ $gi, $include->[$_] ] )
+          for 0 .. ( $grid->nbins - 1 );
 
         # snap bin edges if they are from different grids and are too close.
         # do this in the loop so that there are only two grids at a time
@@ -600,8 +669,10 @@ sub overlay_n {
 
 sub join_n {
 
-# these are called as $sub->( \@edges, \@include, \@right_edges, \@right_include );
-# @edges and @include are mutable and always contain the left grid
+    ## no critic(NamingConventions::ProhibitAmbiguousNames)
+
+    # these are called as $sub->( \@edges, \@include, \@right_edges, \@right_include );
+    # @edges and @include are mutable and always contain the left grid
 
     state %dispatch = (
         'shift-right' => sub {
@@ -673,8 +744,7 @@ sub join_n {
                 push @$include, 1, $rinclude->@*;
             }
             else {
-                parameter_constraint->throw(
-                    "add-bin-include cannot handle overlapping grids" );
+                parameter_constraint->throw( 'add-bin-include cannot handle overlapping grids' );
             }
         },
 
@@ -693,8 +763,7 @@ sub join_n {
                 push @$include, 0, $rinclude->@*;
             }
             else {
-                parameter_constraint->throw(
-                    "add-bin-exclude cannot handle overlapping grids" );
+                parameter_constraint->throw( 'add-bin-exclude cannot handle overlapping grids' );
             }
         },
 
@@ -714,7 +783,7 @@ sub join_n {
                           snap-both
                           include
                           exclude
-                        )
+                        ),
                     ],
                 ],
             ],
@@ -727,12 +796,11 @@ sub join_n {
 
     $opts->{gap} //= 'include';
 
-    parameter_interface->throw( "join_n: no grids supplied" )
+    parameter_interface->throw( 'join_n: no grids supplied' )
       unless $grids->@*;
 
     # sort grids
-    my @grid_idx = sort { $grids->[$a]->min <=> $grids->[$b]->min }
-      0 .. ( $grids->@* - 1 );
+    my @grid_idx = sort { $grids->[$a]->min <=> $grids->[$b]->min } 0 .. ( $grids->@* - 1 );
 
     my ( $left, @rest ) = @grid_idx;
     my $gl = $grids->[$left];
@@ -746,13 +814,12 @@ sub join_n {
 
         $gr = $grids->[$right];
 
-        parameter_constraint->throw(
-            "grid[$right] overlaps grid[$left] by more than one bin" )
+        ## no critic( ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions )
+        parameter_constraint->throw( "grid[$right] overlaps grid[$left] by more than one bin" )
           unless $gl->_raw_edges->[-2] < $gr->_raw_edges->[0]
           && $gl->_raw_edges->[-1] < $gr->_raw_edges->[1];
 
-        my $join = $dispatch{ $opts->{gap} }
-          // internal->throw( "unexpected dispatch key: $opts->{gap}" );
+        my $join = $dispatch{ $opts->{gap} } // internal->throw( "unexpected dispatch key: $opts->{gap}" );
 
         eval {
             $join->( \@edges, \@include, $gr->_raw_edges, $gr->_include );
@@ -791,7 +858,7 @@ sub join_n {
 
 
 
-sub not ( $self ) {
+sub not ( $self ) {    ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
     my $hash = $self->TO_HASH;
     $_ = $_ ? 0 : 1 for $hash->{include}->@*;
@@ -821,9 +888,7 @@ sub _overload_not ( $self, $, $ ) {
 sub _overload_or ( $self, $other, $ ) {
 
     $other->$_isa( __PACKAGE__ )
-      or die(
-        "can only perform the | operation between two ${ \__PACKAGE__ } objects "
-      );
+      or die( "can only perform the | operation between two ${ \__PACKAGE__ } objects " );
     return $self->or( $other );
 }
 
@@ -836,7 +901,7 @@ sub _overload_or ( $self, $other, $ ) {
 
 
 
-sub or ( $self, @args ) {
+sub or ( $self, @args ) {    ## no critic (Subroutines::ProhibitBuiltinHomonyms)
     return or_n( $self, @args );
 }
 
@@ -912,12 +977,10 @@ sub combine_bins ( $self ) {
     my $include = $self->include;
 
     my $tr = CXC::Number::Grid::Tree->new( {
-        'equal-p' =>
-          sub { defined $_[0] && defined $_[1] && $_[0] == $_[1] },
+        'equal-p' => sub { defined $_[0] && defined $_[1] && $_[0] == $_[1] },
     } );
 
-    $tr->range_set( $edges->[$_], $edges->[ $_ + 1 ], $include->[$_] )
-      for 0 .. ( $include->@* - 1 );
+    $tr->range_set( $edges->[$_], $edges->[ $_ + 1 ], $include->[$_] ) for 0 .. ( $include->@* - 1 );
 
     return $tr->to_grid;
 }
@@ -1013,7 +1076,7 @@ CXC::Number::Grid - A class representing a one dimensional numeric grid
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -1063,8 +1126,10 @@ The constructor takes the following arguments:
 
 =item C<edges> => I<array of numbers or Math::BigFloat objects>
 
-The bin edges in the grid. Will be converted to L<Math::BigFloat> objects if they're not already.
-These must be in ascending order.
+The bin edges in the grid. Will be converted to L<Math::BigFloat>
+objects if they're not already.  These must be in ascending order.
+
+Specify either C<bounds> or C<edges> but not both.
 
 =item C<include> => I<array of Flags>
 
@@ -1078,6 +1143,19 @@ The new lower bound is C<-POSIX::DBL_MAX> and the new upper bounds
 will be C<POSIX::DBL_MAX>.  This allows out-of-bounds data to be accumulated
 at the front and back of the grid.
 
+=item C<bounds> => I<array of numbers or Math::BigFloat objects>
+
+Instead of specifying the bin edges, the upper and lower bounds for
+each bin may be specified.  If the supplied bins are not contiguous,
+interstitial bins will be created with an include flag of 0.
+
+The bounds are specified as I<lower bound>, I<upper bound> pairs in the
+passed array, e.g.
+
+   [ $lb0, $ub0, $lb1, $ub1 ]
+
+Specify either C<bounds> or C<edges> but not both.
+
 =back
 
 =head1 METHODS
@@ -1485,13 +1563,14 @@ representation.
 This routine makes copies of the structures so that the hash
 can be modified without affecting the parent object.
 
-=for Pod::Coverage BUILD
+=for Pod::Coverage BUILDARGS
+BUILD
 
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number>
 
 =head2 Source
 
