@@ -5,7 +5,7 @@ package CXC::Number::Sequence::Ratio;
 use strict;
 use warnings;
 
-use v5.26;
+use v5.28;
 
 # ABSTRACT: ratio sequence
 
@@ -38,7 +38,7 @@ extends 'CXC::Number::Sequence';
 
 use namespace::clean;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my sub nelem {
     my ( $ratio, $w0, $Dr ) = @_;
@@ -46,9 +46,7 @@ my sub nelem {
     $w0 = $w0->copy->babs;
     $Dr = $Dr->copy->babs;
 
-    return (
-        ( ( $w0 - ( 1 - $ratio ) * $Dr ) / $w0 )->blog / $ratio->copy->blog )
-      ->bceil + 1;
+    return ( ( ( $w0 - ( 1 - $ratio ) * $Dr ) / $w0 )->blog / $ratio->copy->blog )->bceil + 1;
 }
 
 my sub DRn_factory {
@@ -73,8 +71,7 @@ my sub covers_range {
     return if $Dr <= $w0 / ( 1 - $ratio );
 
     my $min_w0 = $Dr * ( 1 - $ratio );
-    parameter_constraint->throw(
-        "spacing ($w0) is too small to cover range; must be >= $min_w0\n" );
+    parameter_constraint->throw( "spacing ($w0) is too small to cover range; must be >= $min_w0\n" );
 }
 
 my sub e0_le_min {
@@ -113,8 +110,7 @@ my %ArgBuild;
 %ArgBuild = (
     ( MIN | SOFT_MAX | W0 | RATIO ),
     sub {
-        { elements =>
-              e0_le_min( $_->ratio, $_->w0, $_->min, $_->soft_max, $_->min ) };
+        { elements => e0_le_min( $_->ratio, $_->w0, $_->min, $_->soft_max, $_->min ) };
     },
 
     ( MIN | NELEM | W0 | RATIO ),
@@ -127,8 +123,7 @@ my %ArgBuild;
 
     ( SOFT_MIN | MAX | W0 | RATIO ),
     sub {
-        { elements =>
-              e0_ge_max( $_->ratio, $_->w0, $_->soft_min, $_->max, $_->max ) };
+        { elements => e0_ge_max( $_->ratio, $_->w0, $_->soft_min, $_->max, $_->max ) };
     },
 
 
@@ -138,8 +133,7 @@ my %ArgBuild;
         my $DRn = DRn_factory( $_->w0, $_->ratio );
         my $E0  = $_->max;
 
-        { elements => [ map { $E0 - $_ } $DRn->( reverse 0 .. $_->nelem - 1 ) ]
-        };
+        { elements => [ map { $E0 - $_ } $DRn->( reverse 0 .. $_->nelem - 1 ) ], };
 
     },
 
@@ -155,14 +149,9 @@ my %ArgBuild;
             # shrink & grow!
             elsif ( $_->e0 < $_->max ) {
 
-                my $low = e0_ge_max(
-                    1 / $_->ratio,
-                    $_->w0 / $_->ratio,
-                    $_->min, $_->e0, $_->e0
-                );
+                my $low = e0_ge_max( 1 / $_->ratio, $_->w0 / $_->ratio, $_->min, $_->e0, $_->e0, );
 
-                my $high
-                  = e0_le_min( $_->ratio, $_->w0, $_->e0, $_->max, $_->e0 );
+                my $high = e0_le_min( $_->ratio, $_->w0, $_->e0, $_->max, $_->e0 );
 
                 # low and high share an edge; remove it.
                 my @elements = ( $low->@* );
@@ -181,8 +170,8 @@ my %ArgBuild;
 );
 
 # need the parens otherwise the => operator turns them into strings
+## no critic(ControlStructures::ProhibitNegativeExpressionsInUnlessAndUntilConditions)
 my @ArgsCrossValidate = ( [
-
         E0 | MIN | MAX,
         sub {
             parameter_constraint->throw( "min < max\n" )
@@ -223,7 +212,7 @@ my @ArgsCrossValidate = ( [
 around BUILDARGS => buildargs_factory(
     map       => \%ArgMap,
     build     => \%ArgBuild,
-    xvalidate => \@ArgsCrossValidate
+    xvalidate => \@ArgsCrossValidate,
 );
 
 
@@ -328,7 +317,7 @@ CXC::Number::Sequence::Ratio - Numeric Sequence with Relative Fractional Spacing
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -535,7 +524,7 @@ results in
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number>
 
 =head2 Source
 
