@@ -2,7 +2,7 @@ package CXC::Number::Sequence::Role::PDL;
 
 # ABSTRACT: Role to return PDL objects from Sequences
 
-use v5.26;
+use v5.28;
 use PDL::Lite ();
 
 use Moo::Role;
@@ -10,7 +10,7 @@ use Moo::Role;
 use experimental 'signatures';
 use namespace::clean;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 sub _convert ( $self, $bignum ) {
     require Ref::Util;
@@ -44,7 +44,7 @@ CXC::Number::Sequence::Role::PDL - Role to return PDL objects from Sequences
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ L<Math::BigFloat> arrays as piddles and passed L<Math::BigFloat> scalars as Perl
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number
+Please report any bugs or feature requests to bug-cxc-number@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number>
 
 =head2 Source
 
